from typing import Final


# ====== CA: Common Attribute ======

class CA:
    Api: Final[str] = "api"

    Auth: Final[str] = "aut"

    Code: Final[str] = "cd"
    Count: Final[str] = "cnt"

    Data: Final[str] = "dt"
    DescriptionFormatted: Final[str] = "desf"
    DescriptionId: Final[str] = "desid"
    DescriptionPlain: Final[str] = "desp"

    List: Final[str] = "lt"
    Login: Final[str] = "lgn"

    Name: Final[str] = "na"

    Password: Final[str] = "pw"

    Result: Final[str] = "ret"

    Signup: Final[str] = "sgu"

    Title: Final[str] = "tt"
    TitleId: Final[str] = "ttid"

    UserId: Final[str] = "uid"

    Word: Final[str] = "w"

    ___Error___: Final[str] = "err"
